_("File|F");
_("Edit|E");
_("Help|H");
_("File|F");
_("Edit|E");
_("Insert|I");
_("Layout|L");
_("View|V");
_("Navigate|N");
_("Documents|D");
_("Help|H");
_("New...|N");
_("New from Template...|T");
_("Open...|O");
_("Import|I");
_("Exit|x");
_("New...|N");
_("New from Template...|T");
_("Open...|O");
_("Close|C");
_("Save|S");
_("Save As...|A");
_("Revert to Saved|R");
_("Version Control|V");
_("Import|I");
_("Export|E");
_("Print...|P");
_("Fax...|F");
_("Exit|x");
_("Register|R");
_("Check In Changes|I");
_("Check Out for Edit|O");
_("Revert to Last Version|L");
_("Undo Last Check In|U");
_("Show History|H");
_("Custom...|C");
_("Preferences...|P");
_("Reconfigure|R");
_("Undo|U");
_("Redo|d");
_("Cut|C");
_("Copy|o");
_("Paste|a");
_("Paste External Selection|x");
_("Find & Replace...|F");
_("Tabular|T");
_("Math|M");
_("Read Only");
_("Spellchecker...|S");
_("Thesaurus...");
_("Check TeX|h");
_("Remove All Error Boxes|E");
_("Open/Close float|l");
_("Preferences...|P");
_("Reconfigure|R");
_("as Lines|L");
_("as Paragraphs|P");
_("Multicolumn|M");
_("Line Top|T");
_("Line Bottom|B");
_("Line Left|L");
_("Line Right|R");
_("Align Left|e");
_("Align Center|C");
_("Align Right|i");
_("V.Align Top|o");
_("V.Align Center|n");
_("V.Align Bottom|V");
_("Add Row|A");
_("Delete Row|w");
_("Add Column|u");
_("Delete Column|D");
_("Make eqnarray|e");
_("Make multline|m");
_("Make align 1 column|1");
_("Make align 2 columns|2");
_("Make align 3 columns|3");
_("Make alignat 2 columns|2");
_("Make alignat 3 columns|3");
_("Toggle numbering|n");
_("Toggle numbering of line|u");
_("Toggle limits|l");
_("Inline formula|I");
_("Displayed formula|D");
_("Eqnarray environment|q");
_("Align environment|A");
_("Align Left|f");
_("Align Center|C");
_("Align Right|R");
_("V.Align Top|T");
_("V.Align Center|e");
_("V.Align Bottom|B");
_("Add Row");
_("Delete Row");
_("Add Column");
_("Delete Column");
_("Math|h");
_("Special Character|S");
_("Citation Reference...|C");
_("Cross Reference...|R");
_("Label...|L");
_("Footnote|F");
_("Marginal Note|M");
_("Index Entry...|I");
_("Index Entry of Preceding Word|W");
_("URL...|U");
_("Note|N");
_("Lists & TOC|O");
_("TeX|T");
_("Minipage|p");
_("Graphics...|G");
_("Tabular Material...|b");
_("Floats|a");
_("Include File...|d");
_("Insert File|e");
_("External Material...|x");
_("Superscript|S");
_("Subscript|u");
_("HFill|H");
_("Hyphenation Point|P");
_("Ligature break|k");
_("Protected Blank|B");
_("Linebreak|L");
_("Ellipsis|i");
_("End of Sentence|E");
_("Ordinary Quote|Q");
_("Menu Separator|M");
_("Inline Formula|I");
_("Display Formula|D");
_("Eqnarray environment|E");
_("AMS align environment|A");
_("AMS alignat environment|t");
_("AMS xalignat environment|x");
_("AMS xxalignat environment");
_("Array environment|y");
_("Cases environment|C");
_("Math Panel...|l");
_("Table of Contents|C");
_("Index List|I");
_("BibTeX Reference...|B");
_("LyX Document...|X");
_("Ascii as Lines...|L");
_("Ascii as Paragraphs...|P");
_("Character...|C");
_("Paragraph...|P");
_("Document...|D");
_("Tabular...|T");
_("Emphasize Style|E");
_("Noun Style|N");
_("Bold Style|B");
_("TeX Style|X");
_("Change Environment Depth|v");
_("Preamble...|r");
_("Start Appendix here|A");
_("Build Program|B");
_("Update|U");
_("LaTeX Logfile|L");
_("Table of Contents|T");
_("Child processes|C");
_("TeX Information|X");
_("Error|E");
_("Note|N");
_("Refs|R");
_("Bookmarks|B");
_("Save Bookmark 1|S");
_("Save Bookmark 2");
_("Save Bookmark 3");
_("Goto Bookmark 1|1");
_("Goto Bookmark 2|2");
_("Goto Bookmark 3|3");
_("Tooltips|o");
_("Introduction|I");
_("Tutorial|T");
_("User's Guide|U");
_("Extended Features|E");
_("Customization|C");
_("Reference Manual|R");
_("FAQ|F");
_("Table of Contents|a");
_("LaTeX Configuration|L");
_("About LyX|X");
_("ACT");
_("AMS");
_("AT_RISE:");
_("Abstract");
_("Accepted");
_("Acknowledgement");
_("Acknowledgement*");
_("Acknowledgements");
_("Acknowledgments");
_("Addchap");
_("Addchap*");
_("Addition");
_("Address");
_("AddressForOffprints");
_("Addsec");
_("Addsec*");
_("Adresse");
_("Affil");
_("Affiliation");
_("Algorithm");
_("And");
_("Anlagen");
_("Anrede");
_("Appendices");
_("Appendix");
_("Arrow");
_("Author");
_("Author_Email");
_("Author_Running");
_("Author_URL");
_("Authorgroup");
_("Authorinfo");
_("Axiom");
_("BLZ");
_("Backaddress");
_("Bank");
_("BankAccount");
_("BankCode");
_("Betreff");
_("Bibliography");
_("Biography");
_("BoardCentered");
_("Brieftext");
_("CC");
_("CURTAIN");
_("Caption");
_("Case");
_("CenteredCaption");
_("Chapter");
_("Chapter*");
_("Chapter_Exercises");
_("ChessBoard");
_("Claim");
_("Claim*");
_("Closing");
_("Code");
_("Comment");
_("Conclusion");
_("Conclusion*");
_("Condition");
_("Conjecture");
_("Conjecture*");
_("CopNum");
_("Copyright");
_("Corollary");
_("Corollary*");
_("Criterion");
_("CrossList");
_("Current_Address");
_("Customer");
_("Date");
_("Datum");
_("Dedication");
_("Dedicatory");
_("Definition");
_("Definition*");
_("Description");
_("Dialogue");
_("EMail");
_("EXT.");
_("Email");
_("Encl");
_("Encl.");
_("End_All_Slides");
_("Enumerate");
_("Example");
_("Example*");
_("Exercise");
_("Extratitle");
_("FADE_IN:");
_("FADE_OUT");
_("FADE_OUT:");
_("Fact");
_("Fact*");
_("FigCaption");
_("FirstAuthor");
_("FirstName");
_("FitBitmap");
_("FitFigure");
_("Foilhead");
_("Footernote");
_("FourAffiliations");
_("FourAuthors");
_("FrontMatter");
_("General");
_("Gruss");
_("HTTP");
_("Headnote");
_("HideMoves");
_("HighLight");
_("INT.");
_("INTERCUT");
_("IhrSchreiben");
_("IhrZeichen");
_("Institute");
_("Institution");
_("InvisibleText");
_("Invoice");
_("Itemize");
_("Journal");
_("Keyword");
_("Keywords");
_("KnightMove");
_("Konto");
_("LaTeX");
_("LaTeX_Title");
_("Labeling");
_("Land");
_("LandscapeSlide");
_("Left_Header");
_("Lemma");
_("Lemma*");
_("Letter");
_("List");
_("ListOfSlides");
_("Literal");
_("Location");
_("Lowertitleback");
_("LyX-Code");
_("Mail");
_("Mainline");
_("MarkBoth");
_("MathLetters");
_("MeinZeichen");
_("Minisec");
_("More");
_("MyRef");
_("My_Address");
_("My_Logo");
_("Myref");
_("Name");
_("Narrative");
_("Notation");
_("Note");
_("Note*");
_("NoteToEditor");
_("Offprint");
_("Offprints");
_("Offsets");
_("Opening");
_("Ort");
_("Overlay");
_("PACS");
_("PS");
_("Paragraph");
_("Paragraph*");
_("Part");
_("Part*");
_("Phone");
_("Place");
_("PlaceFigure");
_("PlaceTable");
_("PortraitSlide");
_("PostalCommend");
_("PostalComment");
_("Postvermerk");
_("Preprint");
_("Problem");
_("ProgressContents");
_("Proof");
_("Property");
_("Proposition");
_("Proposition*");
_("Publishers");
_("Question");
_("Quotation");
_("Quote");
_("REVTEX_Title");
_("Received");
_("Reference");
_("References");
_("Remark");
_("Remark*");
_("Remarks");
_("Restriction");
_("RetourAdresse");
_("ReturnAddress");
_("Revision");
_("RevisionHistory");
_("RevisionRemark");
_("RightHeader");
_("Right_Address");
_("Right_Footer");
_("Right_Header");
_("Rotatefoilhead");
_("RunningAuthor");
_("RunningTitle");
_("Running_LaTeX_Title");
_("SCENE");
_("SCENE*");
_("SGML");
_("Scene");
_("Scrap");
_("Section");
_("Section*");
_("Send_To_Address");
_("Seriate");
_("ShortFoilhead");
_("ShortRotatefoilhead");
_("ShortTitle");
_("Signature");
_("Slide");
_("Slide*");
_("SlideContents");
_("SlideHeading");
_("SlideSubHeading");
_("Solution");
_("Speaker");
_("Specialmail");
_("Stadt");
_("Standard");
_("State");
_("Strasse");
_("Street");
_("SubSection");
_("SubTitle");
_("SubVariation");
_("SubVariation2");
_("SubVariation3");
_("SubVariation4");
_("SubVariation5");
_("Subject");
_("Subjectclass");
_("Subparagraph");
_("Subparagraph*");
_("Subsection");
_("Subsection*");
_("Subsubsection");
_("Subsubsection*");
_("Subtitle");
_("Summary");
_("Surname");
_("TITLE_OVER:");
_("TOC_Author");
_("TOC_Title");
_("TableComments");
_("TableRefs");
_("Telefax");
_("Telefon");
_("Telephone");
_("Telex");
_("Thanks");
_("Theorem");
_("Theorem*");
_("TheoremTemplate");
_("Thesaurus");
_("ThickLine");
_("ThreeAffiliations");
_("ThreeAuthors");
_("TickList");
_("Title");
_("Titlehead");
_("Topic");
_("Town");
_("Transition");
_("Translator");
_("TwoAffiliations");
_("TwoAuthors");
_("URL");
_("Unterschrift");
_("Uppertitleback");
_("Variation");
_("Verbatim");
_("Verse");
_("Verteiler");
_("VisibleText");
_("YourMail");
_("YourRef");
_("Yourmail");
_("Yourref");
_("Zusatz");
_("cc");
_("encl");
_("msnumber");
_("ps");
_("Afrikaans");
_("American");
_("Arabic");
_("Austrian");
_("Bahasa");
_("Belarusian");
_("Basque");
_("Portuguese (Brazil)");
_("Breton");
_("British");
_("Bulgarian");
_("Canadian");
_("French Canadian");
_("Catalan");
_("Croatian");
_("Czech");
_("Danish");
_("Dutch");
_("English");
_("Esperanto");
_("Estonian");
_("Finnish");
_("French");
_("French (GUTenberg)");
_("Galician");
_("German");
_("German (new spelling)");
_("Greek");
_("Hebrew");
_("Irish");
_("Italian");
_("Kazakh");
_("Lsorbian");
_("Magyar");
_("Norsk");
_("Polish");
_("Portugese");
_("Romanian");
_("Russian");
_("Scottish");
_("Serbian");
_("Serbo-Croatian");
_("Spanish");
_("Slovak");
_("Slovene");
_("Swedish");
_("Thai");
_("Turkish");
_("Ukrainian");
_("Usorbian");
_("Welsh");
_("About LyX")
_("Version")
_("Version goes here")
_("Credits")
_("Copyright")
_("&Close")
_("LyX: Enter text")
_("&Dummy")
_("OK")
_("&Cancel")
_("Index")
_("&Key")
_("The citation key")
_("&Label")
_("The label as it appears in the document")
_("&OK")
_("&Close")
_("Bibtex")
_("Databases")
_("BibTeX database to use")
_("New Item")
_("Available BibTeX databases")
_("&Add ...")
_("Add a BibTeX database file")
_("&Delete")
_("Remove the selected database")
_("&Style")
_("The BibTeX style")
_("plain")
_("unsrt")
_("alpha")
_("abbrv")
_("Other ...")
_("The BibTeX style")
_("FIXME !")
_("The name of the style to use")
_("&Browse")
_("Choose a style file")
_("Add bibliography to &TOC")
_("Add bibliography to the table of contents")
_("OK")
_("Cancel")
_("Character")
_("&Family:")
_("Font family")
_("&Series:")
_("Font series")
_("&Language:")
_("Language")
_("Font shape")
_("Font color")
_("S&hape:")
_("Font shape")
_("Font series")
_("&Color:")
_("Font color")
_("Language")
_("&Toggle all")
_("toggle font on all of the above")
_("Never toggled")
_("Si&ze:")
_("Font size")
_("Always toggled")
_("Other font settings")
_("&Misc:")
_("Other font settings")
_("Auto apply")
_("Apply each change automatically")
_("&OK")
_("&Apply")
_("&Close")
_("Citation")
_("&Restore")
_("OK")
_("&Apply")
_("Cancel")
_("Text after")
_("Citation style")
_("Natbib citation style to use")
_("Text before")
_("Info")
_("Citation entry")
_("Search")
_("Search the available citations")
_("Regular E&xpression")
_("Interpret search entry as a regular expression")
_("&Previous")
_("&Case sensitive")
_("Make the search case-sensitive")
_("&Next")
_("Add the selected citation")
_("Remove the selected citation")
_("Move the selected citation up")
_("Move the selected citation down")
_("Available")
_("Selected")
_("New Item")
_("Available citation keys")
_("New Item")
_("Citations currently selected")
_("Text to place after citation")
_("&Full author list")
_("List all authors")
_("Force &upper case")
_("Force upper case in citation")
_("Text to place before citation")
_("Document Layout")
_("Document")
_("&Fonts:")
_("&Pagestyle:")
_("Defa&ult Skip:")
_("F&ont Size:")
_("default")
_("empty")
_("plain")
_("headings")
_("fancy")
_("Spacin&g:")
_("E&xtra Options:")
_("&Class:")
_("smallskip")
_("medskip")
_("bigskip")
_("length")
_("Single")
_("OneHalf")
_("Double")
_("Other")
_("default")
_("10")
_("11")
_("12")
_("Sides")
_("O&ne")
_("&Two")
_("Columns")
_("On&e")
_("T&wo")
_("Separation")
_("&Indent")
_("S&kip")
_("Paper")
_("&Papersize:")
_("Default")
_("Custom")
_("USletter")
_("USlegal")
_("USexecutive")
_("A3")
_("A5")
_("B3")
_("B4")
_("B5")
_("&Special:")
_("None")
_("A4 small Margins (only portrait)")
_("A4 very small Margins (only portrait)")
_("A4 very wide margins (only portrait)")
_("&Use Geometry Package")
_("Orientation")
_("P&ortrait")
_("&Landscape")
_("Margins")
_("&Right:")
_("&Bottom:")
_("L&eft:")
_("&Top:")
_("Custom Papersize")
_("&Width:")
_("&Height:")
_("Foot/Head Margins")
_("&Footskip:")
_("Hea&dsep:")
_("Headhe&ight:")
_("Language")
_("&Language:")
_("Enco&ding:")
_("default")
_("auto")
_("latin1")
_("latin2")
_("latin3")
_("latin4")
_("latin5")
_("latin9")
_("koi8-r")
_("koi8-u")
_("cp866")
_("cp1251")
_("iso88595")
_("Quote Style")
_("&Type:")
_("``text''")
_("''text''")
_(",,text``")
_(",,text''")
_("«text»")
_("»text«")
_("&Single")
_("&Double")
_("Extra")
_("F&loat Placement:")
_("S&ection number depth:")
_("&Table of contents depth:")
_("P&S Driver:")
_("Use A&MS Math")
_("Bullets")
_("Si&ze")
_("default")
_("tiny")
_("script")
_("footnote")
_("small")
_("normal")
_("large")
_("Large")
_("LARGE")
_("huge")
_("Huge")
_("Bullet Depth")
_("&1")
_("&2")
_("&3")
_("&4")
_("&Standard")
_("&Maths")
_("&Ding 1")
_("D&ing 2")
_("Di&ng 3")
_("Din&g 4")
_("&LaTeX")
_("&Restore")
_("OK")
_("&Apply")
_("Cancel")
_("ERT inset display")
_("&Inline")
_("Show ERT inline")
_("&Collapsed")
_("Show ERT button only")
_("&Open")
_("Show ERT contents")
_("OK")
_("&Close")
_("LaTeX Error")
_("LaTeX error messages")
_("&Close")
_("External Material")
_("&Template")
_("Available templates")
_("LaTeX error messages")
_("&Edit file")
_("Edit the file externally")
_("&View file")
_("View the file")
_("&Update")
_("Update the material")
_("&File")
_("Filename")
_("&Browse ...")
_("&Parameters")
_("Parameters")
_("&OK")
_("&Apply")
_("&Close")
_("Form1")
_("&Restore")
_("&OK")
_("&Apply")
_("&Close")
_("Placement")
_("Bottom of the page")
_("Top of the page")
_("Page of floats")
_("Here, if possible")
_("Here, definitely")
_("Form1")
_("File")
_("&File:")
_("File name to include")
_("&Browse ...")
_("Select a file")
_("Screen Options")
_("Width")
_("Monochrome")
_("Grayscale")
_("Color")
_("Do not display")
_("Si&ze:")
_("S&how:")
_("Height")
_("&Draft mode")
_("draft mode")
_("Size")
_("&Scale")
_("&Default")
_("&Custom")
_("%")
_("Keep aspect&ratio")
_("Width")
_("Height")
_("EPS Options")
_("Bounding box")
_("Left &bottom:")
_("Right &top:")
_("Y")
_("X")
_("pt")
_("cm")
_("in")
_("pt")
_("cm")
_("in")
_("pt")
_("cm")
_("in")
_("pt")
_("cm")
_("in")
_("&Get")
_("Get bounding box from file")
_("&Clip to bounding box")
_("clip to bounding box")
_("Extra")
_("Rotation")
_("&Angle:")
_("&Origin:")
_("default")
_("leftTop")
_("leftBottom")
_("leftBaseline")
_("center")
_("centerTop")
_("centerBottom")
_("centerBaseline")
_("rightTop")
_("rightBottom")
_("rightBaseline")
_("referencePoint")
_("LaTeX options")
_("Su&bfigure")
_("The sub-caption for the figure")
_("&Restore")
_("&OK")
_("&Apply")
_("&Close")
_("Include File")
_("Include type")
_("&Include")
_("FIXME")
_("I&nput")
_("FIXME")
_("&Verbatim")
_("FIXME")
_("Options")
_("&Don't typeset")
_("FIXME")
_("Visible &Space")
_("FIXME")
_("&Filename:")
_("File name to include")
_("&Browse ...")
_("Select a file")
_("&OK")
_("&Close")
_("&Load")
_("Load the file")
_("Index")
_("&Keyword")
_("Index entry")
_("OK")
_("Cancel")
_("Log")
_("&Update")
_("Update the display")
_("&Close")
_("Minipage settings")
_("&Width:")
_("Top")
_("Middle")
_("Bottom")
_("Vertical alignment")
_("A&lignment:")
_("Units of width value")
_("Width value")
_("&Units:")
_("&Restore")
_("&OK")
_("&Apply")
_("&Close")
_("Paragraph")
_("&Alignment and Spacing")
_("Alignment:")
_("Justified")
_("Left")
_("Right")
_("Centered")
_("No indentation")
_("Spacing")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("Units:")
_("Unit of Size, Stretch and Slink")
_("Units:")
_("Unit of Size, Stretch and Slink")
_("Value:")
_("Amount of spacing")
_("Stretch:")
_("Margin by which paragraph is allowed to increase")
_("Shrink:")
_("Margin by which paragraph is allowed to decrease")
_("None")
_("DefSkip")
_("SmallSkip")
_("MedSkip")
_("BigSkip")
_("VFill")
_("Custom")
_("Above:")
_("Below:")
_("None")
_("DefSkip")
_("SmallSkip")
_("MedSkip")
_("BigSkip")
_("VFill")
_("Custom")
_("Keep space at the top of the page")
_("Keep space at top of the page")
_("Keep space at the bottom of the page")
_("List environment")
_("Label width:")
_("Label width in list environment")
_("&Lines and Page breaks")
_("Page break")
_("above paragraph")
_("below paragraph")
_("Index entry")
_("Line")
_("above paragraph")
_("below paragraph")
_("&Extra options")
_("Unit:")
_("Centimetres")
_("Inches")
_("Points")
_("Millimetres")
_("Picas")
_("ex Units")
_("em Units")
_("Scaled Points")
_("Big/PS Points")
_("Didot Points")
_("Cicero Points")
_("None")
_("Minipage")
_("Wrap text around floats")
_("Indent whole paragraph")
_("Width:")
_("Minipage options")
_("Start new minipage")
_("HFill between minipage paragraphs")
_("Vertical Alignment:")
_("Top")
_("Middle")
_("Bottom")
_("&Restore")
_("&Apply")
_("&OK")
_("&Cancel")
_("LaTeX pre-amble")
_("The LaTeX pre-amble")
_("&Edit ...")
_("Edit the pre-amble in an external editor")
_("&OK")
_("&Apply")
_("&Close")
_("Print")
_("Print Destination")
_("P&rinter")
_("Send output to the printer")
_("&File")
_("Send output to a file")
_("Send output to the given printer")
_("Send output to a file")
_("&Browse ...")
_("Pages")
_("&All")
_("Print all pages")
_("&Odd")
_("Print odd pages only")
_("&Even")
_("Print even pages only")
_("&Last page:")
_("Page number to print to")
_("Re&verse order")
_("Print in reverse order")
_("Page number to print from")
_("Ran&ge")
_("Set a range of pages to print")
_("&Starting range:")
_("Copies")
_("Number of copies")
_("&Collate")
_("Collate copies")
_("&Print")
_("Close")
_("Reference")
_("&Type")
_("&Update")
_("Update the reference list")
_("Sort")
_("Sort references in alphabetical order")
_("&Goto")
_("Move the document cursor to reference")
_("Reference")
_("Page number")
_("Ref on page xxx")
_("On page xxx")
_("Pretty reference")
_("Reference as it appears in output")
_("&Reference:")
_("&Name:")
_("Available references")
_("&OK")
_("&Close")
_("Search and replace")
_("&Find:")
_("Replace &with:")
_("Case &sensitive")
_("Match whole words onl&y")
_("Find &Next")
_("&Replace")
_("Replace &All ")
_("Search &backwards")
_("&Close")
_("File: ")
_("&Close")
_("Spellchecker")
_("Suggestions:")
_("&Replace")
_("Replace word with current choice")
_("&Add")
_("Add the word to your personal dictionary")
_("&Ignore")
_("Ignore this word")
_("&Accept")
_("Accept word for this session")
_("&Options...")
_("&Close")
_("How far spellchecking has got")
_("Suggestions")
_("Replacement:")
_("Current word")
_("Unknown:")
_("Replace with selected word")
_("&Start...")
_("Start spellcheck")
_("Insert table")
_("&Rows:")
_("Number of rows")
_("&Columns:")
_("Number of columns")
_("Resize this to the correct table dimensions")
_("&OK")
_("Close")
_("Form1")
_("LaTeX classes")
_("LaTeX styles")
_("BibTeX styles")
_("Selected classes or styles")
_("Show &path")
_("Toggles view of the file list")
_("New Item")
_("Installed files")
_("&Rescan")
_("Built new file list")
_("&View")
_("Show contents of marked file. Only possible when files are shown with path")
_("&Close")
_("Close this dialog")
_("Thesaurus")
_("&Keyword")
_("Index entry")
_("Entry")
_("Thesaurus entries")
_("Select a related word")
_("&Selection")
_("The selected entry")
_("&Replace")
_("Replace the entry with the selection")
_("&Close")
_("Table Of Contents")
_("&Type")
_("Contents list")
_("&Update")
_("&Close")
_("Insert URL")
_("&URL")
_("URL")
_("&Name")
_("Name associated with the URL")
_("URL")
_("&Generate hyperlink")
_("Output as a hyperlink ?")
_("&OK")
_("&Close")
_("Version control log")
_("&Update")
_("Update the display")
_("&Close")
